package com.flyfish.framework.domain.authorized;

import com.flyfish.framework.context.UserContext;
import com.flyfish.framework.domain.base.AuditDomain;
import com.flyfish.framework.domain.po.User;
import com.flyfish.framework.exception.biz.InvalidBusinessException;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;

/**
 * 带鉴权的实体，主要以部门隔绝
 */
@Setter
public abstract class AuthorizedDomain extends AuditDomain {

    // 作用域id，一般是部门。用户存储时插入
    private String authorizeId;

    public String getAuthorizeId() {
        if (StringUtils.isNotBlank(authorizeId)) {
            return authorizeId;
        } else {
            return UserContext.sharedContext()
                    .map(UserContext::currentUser)
                    .map(User::getAuthority)
                    .filter(StringUtils::isNotBlank)
                    .orElseThrow(() -> new InvalidBusinessException("您尚未选择所在部门！请确认您使用的部门身份！"));
        }
    }
}
